--[[
************************************************************************
Project				: SKG
Author				: zhinjio
Project Revision	: r145
Project Date		: 20090517092931

File				: SKG_Globals.lua
Commit Author		: zhinjio
Commit Revision		: 130
Commit Date			: 20090422075512
************************************************************************
Description	:
	This file contains the starting initialization for the addon, as well
	as declarations of all global variables used throughout the remaining
	files. This is the first file in the loading sequence.

TODO		:
	Need to clean up my globals. I really shouldn't need that many at all.
	Put specific references in the files where they are used, and only
	keep those global that are used in many files, many times.

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]

--------------------------------------------------------------------------------------------------
-- Global SKG variables
--------------------------------------------------------------------------------------------------
SKG_VERSION = "r145"
--SKG_VERSION = "r142"

-- SKG_DEBUG = true
SKG_DEBUG = false
SKG_ENABLED = true
SKG_INIT_GUILD = 0
SKG_CHANNEL_PREFIX = "SKG"
SKG_FRAME_STATE =  "Hidden"
SKG_CURRENT_MASTER = ""

-- Possible values here are "(U)ser", "(S)yncer", "(P)roxy", "(A)dmin"
-- Assume lowest level until proven otherwise
SKG_SECURITY_LEVEL = "U"

local SKG = LibStub( "AceAddon-3.0" ):NewAddon(
	"SKG",
--	"AceConfig-3.0",
	"AceConsole-3.0",
	"AceEvent-3.0",
	"AceComm-3.0",
	"AceSerializer-3.0",
	"AceHook-3.0" )
_G["SKG"] = SKG

Dewdrop = LibStub( "Dewdrop-2.0" )
Tablet = LibStub( "Tablet-2.0" )

-- Mapping of Help System Indexes to message titles
SKG_Help_NumOptions = 19
SKG_HelpMap = {
	"SKG_HELP_INTRODUCTION",			-- 1
	"SKG_HELP_BASICS",					-- 2
	"SKG_HELP_MULTIPLERAIDS",			-- 3
	"SKG_HELP_FURTHER",					-- 4
	"SKG_HELP_CREDITS",					-- 5
	"SKG_HELP_USEROPTIONS",				-- 6
	"SKG_HELP_USERBID",					-- 7
	"SKG_HELP_USERRETRACT",				-- 8
	"SKG_HELP_USERSTATUS",				-- 9
	"SKG_HELP_ADMINPLAYERLIST",			-- 10
	"SKG_HELP_ADMINLISTMGMT",			-- 11
	"SKG_HELP_ADMINRESERVE",			-- 12
	"SKG_HELP_ADMINMISSING",			-- 13
	"SKG_HELP_ADMINLOOT",				-- 14
	"SKG_HELP_ADMINFILTER",				-- 15
	"SKG_HELP_ADMINSYNC",				-- 16
	"SKG_HELP_ADMINSECURITY",			-- 17
	"SKG_HELP_ADMINNOTES",				-- 18
	"SKG_HELP_ADMINWEB",				-- 19
}

SKG_maxVisibleListItems = 24
SKG_maxVisibleSYFListItems = 15
SKG_maxVisibleBidItems = 7
SKG_maxVisibleBidders = 8
SKG_currentSyncItems = 0
SKG_currentBidItems = 0
SKG_currentBidders = 0
SKG_SelectedPlayerName = ""
SKG.selectedBidItem = 0
SKG.selectedPID = 0

-- Used for player insertion...
SKG.isAlt = false
SKG.selectedToon = ""
SKG.mainPID = ""
SKG.formSubmit = false
SKG.selectedClass = 0

-- used for tracking if we're in a raid, and the list of current raid members
SKG.inRaid = false
SKG.Raiders = {}

-- Used when importing old settings
SKG.Import = {}
SKG.Import.Players = {}
SKG.Import.RollLists = {}
SKG.importClassSelections = {}
SKG.importSelectedClass = 0
SKG.importCurrPID = ""

-- if I'm syncing with someone, and want to override a bad sync starting 
-- point, I need to store the data somewhere temporarily. This is that place
SKG.OverideData = {}

-- Loot handling stuff
-- bitfield order ...
--	DRUID HUNTER MAGE PALADIN PRIEST ROGUE SHAMAN WARLOCK WARRIOR DEATHKNIGHT
SKG.LootFilter = "1111111111"
SKG.afModify = "1111111111"
SKG.LootItems = { }

SKG.ManagingBidEvent = false
SKG.BidItem = 0
SKG.BidFilter = "1111111111"
SKG.CurrBidList = ""
SKG.Bidders = {}
SKG.OpenedChest = ""
SKG.DE = false

-- Used for loot events involving a non-monster (chests, et al)
SKG.OpenedChest = ""

-- Note, unencoded security info is now only stored runtime, and not in the SV tree
SKG.SecurityInfo = {}

SKG.me = ""

-- Structure for reserved players
--		Reserved players are those that are NOT in the current raid, but
--		DO behave as if they are when a suicide occurs, i.e. they still
--		move through the lists as if they were present.
SKG.ReservedPlayers = {}

-- Sorted version of the SKG.db.profiles.Players list
SKG.SPlayers = {}

-- Reference... from Fonts.XML
-- the class colors for players can be found in the following table:
--		RAID_CLASS_COLORS = {
--			["HUNTER"] = { r = 0.67, g = 0.83, b = 0.45 },
--			["WARLOCK"] = { r = 0.58, g = 0.51, b = 0.79 },
--			["PRIEST"] = { r = 1.0, g = 1.0, b = 1.0 },
--			["PALADIN"] = { r = 0.96, g = 0.55, b = 0.73 },
--			["MAGE"] = { r = 0.41, g = 0.8, b = 0.94 },
--			["ROGUE"] = { r = 1.0, g = 0.96, b = 0.41 },
--			["DRUID"] = { r = 1.0, g = 0.49, b = 0.04 },
--			["SHAMAN"] = { r = 0.14, g = 0.35, b = 1.0 },
--			["WARRIOR"] = { r = 0.78, g = 0.61, b = 0.43 }
--			["DEATHKNIGHT"] = { r = 0.77, g = 0.12 , b = 0.23 },
--		};
--
RAID_STRING_COLORS = {
	["HUNTER"] = "FFAAD372",
	["WARLOCK"] = "FF9382C9",
	["PRIEST"] = "FFFFFFFF",
	["PALADIN"] = "FFF48CBA",
	["MAGE"] = "FF68CCEF",
	["ROGUE"] = "FFFFF468",
	["DRUID"] = "FFFF7C0A",
	["SHAMAN"] = "FF2359FF",
	["WARRIOR"] = "FFC69B6D",
	["DEATHKNIGHT"] = "FFC51E3A",
}

-- We do looping on the number of defined classes in various places. Since
-- that may change over time (eg, adding Death Knights) ... use this variable
-- instead.
SKG.numClasses = 10

--[[
************************************************************************
CHANGELOG:
Date : 12/21/08
	Adding filters, etc for Death Knight compatibility

Date : 10/21/08
	Initial attempt with Ace3 instead of LibRock. Probably will require
	major edits once. Added header/footer. Moved a few docs to new doc
	file. 
************************************************************************
]]--